@@ -22,11 +22,12 @@
 #include "libsound/src/capturedevicecontroller.h"
 #include "libsound/src/outputdevicecontroller.h"
 #include "unit.h"
-#include "course.h"
+#include "icourse.h"
 #include "settings.h"
 
 #include "artikulate_debug.h"
 #include <QTemporaryFile>
+#include <QQmlEngine>
 
 Phrase::Phrase(QObject *parent)
     : QObject(parent)
@@ -37,6 +38,8 @@ Phrase::Phrase(QObject *parent)
     , m_skipCounter(0)
     , m_excludedFromUnit(false)
 {
+    QQmlEngine::setObjectOwnership(this, QQmlEngine::CppOwnership);
+
     connect(this, &Phrase::idChanged, this, &Phrase::modified);
     connect(this, &Phrase::typeChanged, this, &Phrase::modified);
     connect(this, &Phrase::textChanged, this, &Phrase::modified);
@@ -47,10 +50,7 @@ Phrase::Phrase(QObject *parent)
     connect(this, &Phrase::excludedChanged, this, &Phrase::modified);
 }
 
-Phrase::~Phrase()
-{
-
-}
+Phrase::~Phrase() = default;
 
 QString Phrase::id() const
 {
@@ -168,9 +168,8 @@ QString Phrase::editStateString() const
         return QStringLiteral("translated");
     case Completed:
         return QStringLiteral("completed");
-    default:
-        return QStringLiteral("ERROR_UNKNOWN_EDIT_STATE");
     }
+    Q_UNREACHABLE();
 }
 
 void Phrase::setEditState(Phrase::EditState state)
@@ -273,15 +272,19 @@ void Phrase::setExcluded(bool excluded)
 
 int Phrase::progress() const
 {
-    return m_trainingProgress;
+    return static_cast<int>(m_trainingProgress);
 }
 
 void Phrase::setProgress(int value)
 {
-    if (m_trainingProgress == value) {
+    Q_ASSERT(value >= 0);
+    if (value < 0) {
+        value = 0;
+    }
+    if (m_trainingProgress == static_cast<uint>(value)) {
         return;
     }
-    m_trainingProgress = value;
+    m_trainingProgress = static_cast<uint>(value);
     emit progressChanged();
 }
 void Phrase::updateProgress(Phrase::Progress progress)
@@ -307,7 +310,7 @@ void Phrase::updateProgress(Phrase::Progress progress)
     }
 }
 
-QList<Phoneme *> Phrase::phonemes() const
+QVector<Phoneme *> Phrase::phonemes() const
 {
     return m_phonemes;
 }
