@@ -23,14 +23,14 @@
 
 #include <QAbstractListModel>
 
-class Course;
+class ICourse;
 class PhonemeGroup;
 class QSignalMapper;
 
 class PhonemeGroupModel : public QAbstractListModel
 {
     Q_OBJECT
-    Q_PROPERTY(Course *course READ course WRITE setCourse NOTIFY courseChanged)
+    Q_PROPERTY(ICourse *course READ course WRITE setCourse NOTIFY courseChanged)
 
 public:
     enum unitRoles {
@@ -43,12 +43,12 @@ public:
     /**
      * Reimplemented from QAbstractListModel::roleNames()
      */
-    virtual QHash<int,QByteArray> roleNames() const Q_DECL_OVERRIDE;
-    void setCourse(Course *course);
-    Course * course() const;
-    virtual QVariant data(const QModelIndex &index, int role = Qt::DisplayRole) const Q_DECL_OVERRIDE;
-    virtual int rowCount(const QModelIndex &parent = QModelIndex()) const Q_DECL_OVERRIDE;
-    virtual QVariant headerData(int section, Qt::Orientation orientation, int role = Qt::DisplayRole) const Q_DECL_OVERRIDE;
+    virtual QHash<int,QByteArray> roleNames() const override;
+    void setCourse(ICourse *course);
+    ICourse * course() const;
+    virtual QVariant data(const QModelIndex &index, int role = Qt::DisplayRole) const override;
+    virtual int rowCount(const QModelIndex &parent = QModelIndex()) const override;
+    virtual QVariant headerData(int section, Qt::Orientation orientation, int role = Qt::DisplayRole) const override;
 
 signals:
     void phonemeGroupChanged(int index);
@@ -63,7 +63,7 @@ private slots:
 
 private:
     void updateMappings();
-    Course *m_course;
+    ICourse *m_course;
     QSignalMapper *m_signalMapper;
 };
 
